@@ -148,6 +148,7 @@ struct _AisleriotWindowPrivate
   guint changing_game_type : 1;
   guint freecell_mode : 1;
   guint toolbar_visible : 1;
+  guint statusbar_visible : 1;
 };
 
 enum {
@@ -735,31 +736,86 @@ debug_exception_cb (GtkAction *action,
   aisleriot_game_generate_exception (priv->game);
 }
 
+#define DEBUG_WINDOW_DATA_KEY "debug-data"
+
 typedef struct {
   AisleriotWindow *window;
   GList *games_list;
-} DebugCycleData;
+  GList *current_game;
+} DebugWindowData;
+
+static void
+debug_data_free (DebugWindowData *data)
+{
+  g_list_foreach (data->games_list, (GFunc) g_free, NULL);
+  g_list_free (data->games_list);
+  g_slice_free (DebugWindowData, data);
+}
+
+static DebugWindowData *
+debug_ensure_game_list (AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+  DebugWindowData *data;
+  GamesFileList *files;
+  GList *l;
+
+  data = g_object_get_data (G_OBJECT (window), DEBUG_WINDOW_DATA_KEY);
+  if (data != NULL)
+    return data;
+
+  files = games_file_list_new ("*.scm", games_path_runtime_fix (GAMESDIR), NULL);
+  games_file_list_transform_basename (files);
+
+  data = g_slice_new (DebugWindowData);
+  data->window = window;
+  data->games_list = files->list;
+  data->current_game = g_list_find_custom (data->games_list,
+                                           aisleriot_game_get_game_file (priv->game),
+                                           (GCompareFunc) strcmp);
+
+  /* Remove the base sol.scm from the list */
+  for (l = data->games_list; l != NULL; l = l->next) {
+    char *game_file = (char *) l->data;
+
+    if (game_file != NULL &&
+        strcmp (game_file, "sol.scm") == 0) {
+      data->games_list = g_list_delete_link (data->games_list, l);
+      g_free (game_file);
+      break;
+    }
+  }
+
+  files->list = NULL;
+  g_object_unref (files);
+
+  g_object_set_data_full (G_OBJECT (window), DEBUG_WINDOW_DATA_KEY,
+                          data, (GDestroyNotify) debug_data_free);
+
+  return data;
+}
 
 static gboolean
-debug_cycle_timeout_cb (DebugCycleData *data)
+debug_cycle_timeout_cb (AisleriotWindow *window)
 {
+  DebugWindowData *data;
   char *game_file;
 
-  if (data->games_list == NULL) {
-    g_slice_free (DebugCycleData, data);
+  data = debug_ensure_game_list (window);
+  if (data->current_game != NULL) {
+    data->current_game = data->current_game->next;
+    /* We're done */
+    if (!data->current_game)
+      return FALSE;
+  }
+  if (!data->current_game) {
+    data->current_game = data->games_list;
+  }
+  if (!data->current_game)
     return FALSE;
-  }
 
-  game_file = data->games_list->data;
-  /* Take the head off of the list */
-  data->games_list = g_list_delete_link (data->games_list, data->games_list);
-
-  if (game_file != NULL &&
-      strcmp (game_file, "sol.scm") != 0) {
-    aisleriot_window_set_game (data->window, game_file, 0);
-  }
-
-  g_free (game_file);
+  game_file = data->current_game->data;  
+  aisleriot_window_set_game (data->window, game_file, 0);
 
   return TRUE;
 }
@@ -768,20 +824,73 @@ static void
 debug_cycle_cb (GtkAction *action,
                 AisleriotWindow *window)
 {
-  GamesFileList *files;
-  DebugCycleData *data;
+  g_timeout_add (500, (GSourceFunc) debug_cycle_timeout_cb, window);
+}
 
-  files = games_file_list_new ("*.scm", games_path_runtime_fix (GAMESDIR), NULL);
-  games_file_list_transform_basename (files);
+static void
+debug_game_first (GtkAction *action,
+                  AisleriotWindow *window)
+{
+  DebugWindowData *data;
 
-  data = g_slice_new (DebugCycleData);
-  data->window = window;
-  data->games_list = files->list;
+  data = debug_ensure_game_list (window);
+  data->current_game = data->games_list;
+  if (!data->current_game)
+    return;
 
-  files->list = NULL;
-  g_object_unref (files);
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
+}
 
-  g_timeout_add (500, (GSourceFunc) debug_cycle_timeout_cb, data);
+static void
+debug_game_last (GtkAction *action,
+                 AisleriotWindow *window)
+{
+  DebugWindowData *data;
+
+  data = debug_ensure_game_list (window);
+  data->current_game = g_list_last (data->games_list);
+  if (!data->current_game)
+    return;
+
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
+}
+
+static void
+debug_game_next (GtkAction *action,
+                 AisleriotWindow *window)
+{
+  DebugWindowData *data;
+
+  data = debug_ensure_game_list (window);
+  if (data->current_game) {
+    data->current_game = data->current_game->next;
+  }
+  if (!data->current_game) {
+    data->current_game = data->games_list;
+  }
+  if (!data->current_game)
+    return;
+
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
+}
+
+static void
+debug_game_prev (GtkAction *action,
+                 AisleriotWindow *window)
+{
+  DebugWindowData *data;
+
+  data = debug_ensure_game_list (window);
+  if (data->current_game) {
+    data->current_game = data->current_game->prev;
+  }
+  if (!data->current_game) {
+    data->current_game = data->games_list;
+  }
+  if (!data->current_game)
+    return;
+
+  aisleriot_window_set_game (data->window, (const char *) data->current_game->data, 0);
 }
 
 #endif /* !HAVE_HILDON */
@@ -805,6 +914,8 @@ debug_choose_seed_response_cb (GtkWidget *dialog,
     seed = g_ascii_strtoull (text, &endptr, 10);
     if (errno == 0 && endptr != text) {
       aisleriot_game_new_game (priv->game, &seed);
+
+      gtk_widget_grab_focus (GTK_WIDGET (priv->board));
     }
   }
 
@@ -824,7 +935,7 @@ debug_choose_seed_cb (GtkAction *action,
                                    GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_OK_CANCEL,
-                                   "Choose game seed");
+                                   "%s", "Choose game seed");
   g_signal_connect (dialog, "response",
                     G_CALLBACK (debug_choose_seed_response_cb), window);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
@@ -869,6 +980,22 @@ toolbar_toggled_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), state);
 }
 
+static void
+statusbar_toggled_cb (GtkToggleAction *action,
+                      AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+  gboolean state;
+
+  state = gtk_toggle_action_get_active (action);
+
+  g_object_set (priv->statusbar, "visible", state, NULL);
+
+  priv->statusbar_visible = state != FALSE;
+
+  games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), state);
+}
+
 static void
 set_fullscreen_actions (AisleriotWindow *window,
                         gboolean is_fullscreen)
@@ -1836,7 +1963,7 @@ game_exception_cb (AisleriotGame *game,
                                    GTK_DIALOG_DESTROY_WITH_PARENT,
                                    GTK_MESSAGE_ERROR,
                                    GTK_BUTTONS_NONE,
-                                   _("A scheme exception occurred"));
+                                   "%s", _("A scheme exception occurred"));
   gtk_message_dialog_format_secondary_text
     (GTK_MESSAGE_DIALOG (dialog),
      "%s", _("Please report this bug to the developers."));
@@ -1881,7 +2008,9 @@ aisleriot_window_state_event (GtkWidget *widget,
                               GdkEventWindowState *event)
 {
   AisleriotWindow *window = AISLERIOT_WINDOW (widget);
+#ifndef HAVE_HILDON
   AisleriotWindowPrivate *priv = window->priv;
+#endif
 
   if (event->changed_mask & (GDK_WINDOW_STATE_FULLSCREEN | GDK_WINDOW_STATE_MAXIMIZED)) {
     gboolean is_fullscreen, is_maximised;
@@ -1969,7 +2098,7 @@ aisleriot_window_init (AisleriotWindow *window)
     { "RedoMove", GAMES_STOCK_REDO_MOVE, NULL, NULL,
       ACTION_TOOLTIP (N_("Redo the undone move")),
       G_CALLBACK (redo_cb) },
-    { "Deal", GTK_STOCK_OK /* FIXMEchpe */, _("_Deal"), "<control>D",
+    { "Deal", GAMES_STOCK_DEAL_CARDS, NULL, NULL,
       ACTION_TOOLTIP (N_("Deal next card or cards")),
       G_CALLBACK (deal_cb) },
     { "Hint", GAMES_STOCK_HINT, NULL, NULL,
@@ -2009,6 +2138,14 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (debug_exception_cb) },
     { "DebugCycle", NULL, "Cycle through _all games", NULL, NULL,
       G_CALLBACK (debug_cycle_cb) },
+    { "DebugGameFirst", GTK_STOCK_GOTO_FIRST, NULL, NULL, NULL,
+      G_CALLBACK (debug_game_first) },
+    { "DebugGameLast", GTK_STOCK_GOTO_LAST, NULL, NULL, NULL,
+      G_CALLBACK (debug_game_last) },
+    { "DebugGameNext", GTK_STOCK_GO_FORWARD, NULL, NULL, NULL,
+      G_CALLBACK (debug_game_next) },
+    { "DebugGamePrev", GTK_STOCK_GO_BACK, NULL, NULL, NULL,
+      G_CALLBACK (debug_game_prev) },
 #endif /* !HAVE_HILDON */
 #endif /* ENABLE_DEBUG_UI */
 
@@ -2026,7 +2163,12 @@ aisleriot_window_init (AisleriotWindow *window)
     { "Toolbar", NULL, N_("_Toolbar"), NULL,
       ACTION_TOOLTIP (N_("Show or hide the toolbar")),
       G_CALLBACK (toolbar_toggled_cb),
-      TRUE /* active by default */
+      FALSE
+    },
+    { "Statusbar", NULL, N_("_Statusbar"), NULL,
+      ACTION_TOOLTIP (N_("Show or hide statusbar")),
+      G_CALLBACK (statusbar_toggled_cb),
+      FALSE
     },
     { "ClickToMove", NULL, N_("_Click to Move"), NULL,
       ACTION_TOOLTIP (N_("Pick up and drop cards by clicking")),
@@ -2116,6 +2258,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "<menu action='ViewMenu'>"
           "<menuitem action='Fullscreen'/>"
           "<menuitem action='Toolbar'/>"
+          "<menuitem action='Statusbar'/>"
           "<separator/>"
           "<menu action='ThemeMenu'/>"
         "</menu>"
@@ -2142,7 +2285,13 @@ aisleriot_window_init (AisleriotWindow *window)
           "<menuitem action='DebugMoveNextScreen'/>"
           "<menuitem action='DebugDelayedMoveNextScreen'/>"
           "<menuitem action='DebugException'/>"
+          "<separator/>"
           "<menuitem action='DebugCycle'/>"
+          "<separator/>"
+          "<menuitem action='DebugGameFirst'/>"
+          "<menuitem action='DebugGamePrev'/>"
+          "<menuitem action='DebugGameNext'/>"
+          "<menuitem action='DebugGameLast'/>"
         "</menu>"
 #endif /* ENABLE_DEBUG_UI */
       "</menubar>"
@@ -2159,6 +2308,12 @@ aisleriot_window_init (AisleriotWindow *window)
 #ifndef HAVE_MAEMO
         "<toolitem action='LeaveFullscreen'/>"
 #endif
+#ifdef ENABLE_DEBUG_UI
+        "<toolitem action='DebugGameFirst'/>"
+        "<toolitem action='DebugGamePrev'/>"
+        "<toolitem action='DebugGameNext'/>"
+        "<toolitem action='DebugGameLast'/>"
+#endif
 #ifdef HAVE_MAEMO
         "<separator/>"
 #endif
@@ -2223,7 +2378,11 @@ aisleriot_window_init (AisleriotWindow *window)
 
   aisleriot_board_set_pixbuf_drawing (priv->board, priv->use_pixbuf_drawing);
 
-  theme = games_conf_get_string_with_default (NULL, aisleriot_conf_get_key (CONF_THEME), GAMES_CARD_THEME_DEFAULT);
+  theme = games_conf_get_string (NULL, aisleriot_conf_get_key (CONF_THEME), NULL);
+  if (!theme || !theme[0]) {
+    g_free (theme);
+    theme = g_strdup (GAMES_CARD_THEME_DEFAULT);
+  }
 #ifdef HAVE_GNOME
   /* Compatibility with old settings */
   if (g_str_has_suffix (theme, ".svg")) {
@@ -2349,6 +2508,10 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->toolbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), NULL) != FALSE;
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 priv->toolbar_visible);
+  action = gtk_action_group_get_action (priv->action_group, "Statusbar");
+  priv->statusbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), NULL) != FALSE;
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+                                priv->statusbar_visible);
   action = gtk_action_group_get_action (priv->action_group, "ClickToMove");
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), NULL));
@@ -2373,7 +2536,6 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_box_pack_start (GTK_BOX (main_vbox), priv->main_menu, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (main_vbox), priv->toolbar, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (main_vbox), GTK_WIDGET (priv->statusbar), FALSE, FALSE, 0);
-  gtk_widget_show (GTK_WIDGET (priv->statusbar));
 #endif /* HAVE_HILDON */
 
   gtk_box_pack_start (GTK_BOX (main_vbox), GTK_WIDGET (priv->board), TRUE, TRUE, 0);
