@@ -29,7 +29,7 @@ else:
         try:
             glConfig = gtk.gdkgl.Config(mode = display_mode)
         except gtk.gdkgl.NoMatches:
-            openGLErrors(_('OpenGL libraries do not support required display mode'))
+            openGLErrors.append(_('OpenGL libraries do not support required display mode'))
 haveGLSupport = len(openGLErrors) == 0
 
 __all__ = ['GtkView']
@@ -110,8 +110,12 @@ class GtkViewArea(gtk.DrawingArea):
         glDrawable = gtk.gtkgl.widget_get_gl_drawable(self)
         glContext = gtk.gtkgl.widget_get_gl_context(self)
 
-        # OpenGL begin.
-        if glDrawable is None or not glDrawable.gl_begin(glContext):
+        # Check were able to get context
+        if glDrawable is None or glContext is None:
+            return
+
+        # OpenGL begin (can fail)
+        if not glDrawable.gl_begin(glContext):
             return
         
         self.__glDrawable = glDrawable
@@ -477,12 +481,7 @@ class GtkView(glchess.ui.ViewController):
         elif game.rule is glchess.game.RULE_THREE_FOLD_REPETITION:
             description = _('The same board state has occured three times (three fold repetition)')
         elif game.rule is glchess.game.RULE_INSUFFICIENT_MATERIAL:
-            if game.result is glchess.game.RESULT_DRAW:
-                description = _('Neither player can cause checkmate (insufficient material)')
-            elif game.result is glchess.game.RESULT_WHITE_WINS:
-                description = _('Black player is unable to cause checkmate (insufficient material)')
-            elif game.result is glchess.game.RESULT_BLACK_WINS:
-                description = _('White player is unable to cause checkmate (insufficient material)')
+            description = _('Neither player can cause checkmate (insufficient material)')
         elif game.rule is glchess.game.RULE_RESIGN:
             if game.result is glchess.game.RESULT_WHITE_WINS:
                 description = _('The black player has resigned')
