@@ -157,6 +157,10 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         if self._throbberTimer is not None:
             gobject.source_remove(self._throbberTimer)
             self._throbberTimer = None
+
+        # Disable room buttons when busy
+        widget = self.__gui.get_widget('room_button_box')
+        widget.set_sensitive(not isBusy)
         
         # Display animating frames if busy or idle frame if not
         if isBusy:
@@ -341,12 +345,18 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         size = 32
         self._throbberFrames = []
         
-        icon = theme.load_icon('process-idle', size, 0)
-        if icon is not None:
+        try:
+            icon = theme.load_icon('process-idle', size, 0)
+        except gobject.GError:
+            pass
+        else:
             self._throbberFrames.append(icon)
 
-        icon = theme.load_icon('process-working', size, 0)
-        if icon is not None:
+        try:
+            icon = theme.load_icon('process-working', size, 0)
+        except gobject.GError:
+            pass
+        else:
             # If a smaller icon was received than expected then use that size
             height = icon.get_height()
             width = icon.get_width()
