@@ -359,7 +359,6 @@ class Scene(glchess.scene.Scene):
         glRenderMode(GL_SELECT)
 
         glInitNames()
-        glPushName(0)
 
         # Create pixel picking region near cursor location
         glMatrixMode(GL_PROJECTION)
@@ -382,14 +381,13 @@ class Scene(glchess.scene.Scene):
         try:
             records = glRenderMode(GL_RENDER)
         except GLerror:
-            records = None
-
-        # Get the first record and use this as the selected square
-        coord = None
-        if records is not None:
-            for record in records:
-                coord = record[2]
-                break
+            coord = None
+        else:
+            # Get the first record and use this as the selected square
+            if len(records) > 0:
+                (_, _, coord) = records[0]
+            else:
+                coord = None
 
         # Reset projection matrix
         glMatrixMode(GL_PROJECTION)
@@ -622,9 +620,13 @@ class Scene(glchess.scene.Scene):
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT)
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR)
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR)
-        gluBuild2DMipmaps(GL_TEXTURE_2D, GL_ALPHA, TEXTURE_WIDTH, TEXTURE_HEIGHT,
-                          GL_ALPHA, GL_UNSIGNED_BYTE, str(data))
-                          
+        
+        try:
+            gluBuild2DMipmaps(GL_TEXTURE_2D, GL_ALPHA, TEXTURE_WIDTH, TEXTURE_HEIGHT,
+                              GL_ALPHA, GL_UNSIGNED_BYTE, str(data))
+        except GLUerror, e:
+            glTexImage2D(GL_TEXTURE_2D, 0, GL_ALPHA, TEXTURE_WIDTH, TEXTURE_HEIGHT, 0, GL_ALPHA, GL_UNSIGNED_BYTE, str(data))
+            
         return t
     
     def drawNumbering(self):
@@ -694,7 +696,7 @@ class Scene(glchess.scene.Scene):
 
         # If have a list store there
         if self.boardList is not None:
-            glNewList(self.boardList, GL_COMPILE_AND_EXECUTE)
+            glNewList(self.boardList, GL_COMPILE)
             
         # Board verticies
         # (lower 12-15 are under 8-11)
@@ -808,10 +810,10 @@ class Scene(glchess.scene.Scene):
         
     def drawSquares(self):
         """Draw the board squares for picking"""
-
+        
         # draw the floor squares
         for u in [0, 1, 2, 3, 4, 5, 6, 7]:
-            glLoadName(u)
+            glPushName(u)
 
             for v in [0, 1, 2, 3, 4, 5, 6, 7]:
                 glPushName(v)
@@ -830,6 +832,7 @@ class Scene(glchess.scene.Scene):
                 glEnd()
 
                 glPopName()
+            glPopName()
         
     def drawPieces(self):
         """Draw the pieces in the scene"""
