@@ -30,8 +30,7 @@ def super_setattr (obj, attr, val):
 def jar_game (ui):
     jar = {} # what we will pickle
     #jar['undo_history']=ui.history
-    ui.timer.resume_timing()
-    ui.timer.toggle_timing(False) # Save time...
+    ui.timer.finish_timing()
     jar['game']=ui.gsd.grid.to_string()
     jar['trackers']=ui.gsd.trackers
     jar['tracking']=ui.gsd.__trackers_tracking__
