@@ -41,6 +41,7 @@
 #include <dirent.h>
 #include <string.h>
 #include <math.h>
+#include <ctype.h>
 
 int LINES = 20;
 int COLUMNS = 14;
@@ -977,9 +978,9 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 	if (t->timeoutId == 0)
 		return FALSE;
 
-	keyval = ((GdkEventKey*)event)->keyval;
+	keyval = toupper(((GdkEventKey*)event)->keyval);
 
-	if (keyval == t->movePause)
+	if (keyval == toupper(t->movePause))
 	{
 		t->togglePause();
 		return TRUE;
@@ -988,29 +989,29 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 	if (t->paused)
 		return FALSE;
 
-	if (keyval == t->moveLeft) {
+	if (keyval == toupper(t->moveLeft)) {
 		res = t->field->moveBlockLeft();
 		if (res)
 			games_sound_play ("slide");
 		t->onePause = false;
-	} else if (keyval == t->moveRight) {
+	} else if (keyval == toupper(t->moveRight)) {
 		res = t->field->moveBlockRight();
 		if (res)
 			games_sound_play ("slide");
 		t->onePause = false;
-	} else if (keyval == t->moveRotate) {
+	} else if (keyval == toupper(t->moveRotate)) {
 		res = t->field->rotateBlock(rotateCounterClockWise);
 		if (res)
 			games_sound_play ("turn");
 		t->onePause = false;
-	} else if (keyval == t->moveDown) {
+	} else if (keyval == toupper(t->moveDown)) {
 		if (!t->fastFall && !t->onePause) {
 			t->fastFall = true;
 			g_source_remove (t->timeoutId);
 			t->timeoutId = g_timeout_add (10, timeoutHandler, t);
 			res = true;
 		}
-	} else if (keyval == t->moveDrop) {
+	} else if (keyval == toupper(t->moveDrop)) {
 		if (!t->dropBlock) {
 			t->dropBlock = true;
 			t->field->dropBlock();
@@ -1371,7 +1372,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 {
 	Tetris *t = (Tetris*) d;
 
-	const gchar * const authors[] = { "J. Marcin Gorycki", NULL };
+	const gchar * const authors[] = { "Gnome Games Team", NULL };
 
 	const gchar * const documenters[] = { "Angela Boyle", NULL };
 
@@ -1385,7 +1386,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 #endif
 			       "version", VERSION,
 			       "comments", _("A classic game of fitting falling blocks together.\n\nGnometris is a part of GNOME Games."),
-			       "copyright", "Copyright \xc2\xa9 1999-2008 J. Marcin Gorycki",
+			       "copyright", "Copyright \xc2\xa9 1999 J. Marcin Gorycki, 2000-2008 Others",
 			       "license", license,
 		               "website-label", _("GNOME Games web site"),
 			       "authors", authors,
