@@ -993,15 +993,15 @@ gtk_minefield_motion_notify (GtkWidget * widget, GdkEventMotion * event)
   if (mfield->lose || mfield->win)
     return FALSE;
 
-  if (mfield->bdown[0] || mfield->bdown[1]) {
-    x = event->x / minesize;
-    y = event->y / minesize;
+  x = event->x / minesize;
+  y = event->y / minesize;
 
-    c = cell_idx (mfield, x, y);
-    if (c == -1)
-      return 0;
+  c = cell_idx (mfield, x, y);
+  if (c == -1)
+    return 0;
 
-    if (c != mfield->cdown) {
+  if (c != mfield->cdown) {
+    if (mfield->bdown[0] || mfield->bdown[1]) {
       mfield->mines[mfield->cdown].down = 0;
       gtk_mine_draw (mfield, mfield->cdownx, mfield->cdowny);
 
@@ -1016,6 +1016,16 @@ gtk_minefield_motion_notify (GtkWidget * widget, GdkEventMotion * event)
 
       if (mfield->action == CLEAR_ACTION && mfield->mines[c].shown)
         gtk_minefield_multi_press (mfield, x, y, c);
+    } else if (mfield->bdown[2]) {
+      /*  Update clicked field on right click drag. See bug #  */
+      mfield->mines[mfield->cdown].down = 0;
+      mfield->action = NO_ACTION;
+      gtk_mine_draw (mfield, mfield->cdownx, mfield->cdowny);
+
+      mfield->cdownx = x;
+      mfield->cdowny = y;
+      mfield->cdown = c;
+      mfield->mines[c].down = 1;
     }
   }
   return FALSE;
@@ -1077,6 +1087,9 @@ gtk_minefield_button_press (GtkWidget * widget, GdkEventButton * event)
       mfield->action = SHOW_ACTION;
       if ((event->state & GDK_SHIFT_MASK) || (mfield->bdown[2]) || (mfield->mines[c].shown))
         mfield->action = CLEAR_ACTION;
+      /* Ctrl + left = right to make game playable on touchpad */
+      if (event->state & GDK_CONTROL_MASK)
+        mfield->action = FLAG_ACTION;
       break;
     case 2:
       mfield->action = CLEAR_ACTION;
@@ -1092,8 +1105,10 @@ gtk_minefield_button_press (GtkWidget * widget, GdkEventButton * event)
      * is done in the button_release handler. */
     if (mfield->action == CLEAR_ACTION) {
       gtk_minefield_multi_press (mfield, x, y, c);
-    } else if (mfield->action == FLAG_ACTION && mfield->bdown[2] == 1) {
-      gtk_minefield_toggle_mark (mfield, x, y);
+    } else if (mfield->action == FLAG_ACTION) {
+      if (mfield->bdown[2] == 1 || (event->state & GDK_CONTROL_MASK && mfield->bdown[0] == 1)) {
+        gtk_minefield_toggle_mark (mfield, x, y);
+      }
     }
     if (mfield->action != FLAG_ACTION) {
       g_signal_emit (GTK_OBJECT (mfield),
